---
name: Bug report
about: Create a report to help us improve
title: 'Bug: '
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Please provide a minimal reproducible example that developers can run to investigate the problem.
You can find help for creating such an example [here](https://stackoverflow.com/help/minimal-reproducible-example).

**Environment (please complete the following information):**

- openapipages version: [e.g. 0.1.0]
- Backend: [FastAPI, Starlette, ...]

**Additional context**
Add any other context about the problem here.
